
Create lat.layout table by running `bmad_to_blender` in this direcory. This will read `lat.bmad` and create `lat.layout_table`.

This should do:
```bash
$ bmad_to_blender
 Opening: bmad_to_blender.in
[INFO] bmad_parser:
    Parsing lattice file(s). This might take a minute or so...
[INFO] bmad_parser:
    Created new digested file
[MESSAGE | 2023-NOV-26 12:23:16] bmad_parser:
    Lattice parse time(min): 0.00
lat.layout_table written
```
